@@ -11,7 +11,6 @@ from fsspec.core import open_files
 from dask.base import compute as dask_compute
 from dask.bytes import read_bytes
 from dask.core import flatten
-from dask.dataframe._compat import PANDAS_GE_200, PANDAS_VERSION
 from dask.dataframe.backends import dataframe_creation_dispatch
 from dask.dataframe.io.io import from_delayed
 from dask.dataframe.utils import insert_meta_param_description, make_meta
@@ -73,9 +72,7 @@ def to_json(
     if lines is None:
         lines = orient == "records"
     if orient != "records" and lines:
-        raise ValueError(
-            "Line-delimited JSON is only available with" 'orient="records".'
-        )
+        raise ValueError('Line-delimited JSON is only available with orient="records".')
     kwargs["orient"] = orient
     kwargs["lines"] = lines and orient == "records"
     outfiles = open_files(
@@ -200,9 +197,7 @@ def read_json(
     if lines is None:
         lines = orient == "records"
     if orient != "records" and lines:
-        raise ValueError(
-            "Line-delimited JSON is only available with" 'orient="records".'
-        )
+        raise ValueError('Line-delimited JSON is only available with orient="records".')
     if blocksize and (orient != "records" or not lines):
         raise ValueError(
             "JSON file chunking only allowed for JSON-lines"
@@ -215,14 +210,8 @@ def read_json(
     if path_converter is None:
         path_converter = lambda x: x
 
-    # Handle engine string (Pandas>=2.0)
+    # Handle engine string
     if isinstance(engine, str):
-        if not PANDAS_GE_200:
-            raise ValueError(
-                f"Pandas>=2.0 is required to pass a string to the "
-                f"`engine` argument of `read_json` "
-                f"(pandas={str(PANDAS_VERSION)} is currently installed)."
-            )
         engine = partial(pd.read_json, engine=engine)
 
     if blocksize:
