@@ -1,4 +1,7 @@
+from __future__ import annotations
+
 import pandas as pd
+import pytest
 
 import dask
 import dask.dataframe as dd
@@ -10,6 +13,9 @@ dsk = {
 }
 dfs = list(dsk.values())
 
+if dd._dask_expr_enabled():
+    pytest.skip("doesn't make sense with dask-expr", allow_module_level=True)
+
 
 def test_fuse_ave_width():
     df = pd.DataFrame({"x": range(10)})
